@@ -40,7 +40,7 @@ metadata = {'creator': {'name': 'Unknown',
                             },
             'reduction': {'software': {'name': 'islatu',
                                        'link': 'https://islatu.readthedocs.io',
-                                       'version': '0.0.38'},
+                                       'version': '0.0.39'},
                           'yaml': 'Unknown',
                           'input files': {'datafiles': []},
                           'data state': {}}
@@ -75,7 +75,7 @@ class Foreperson:
         self.metadata = metadata
 
     def ready(self, directory):
-        directory_path = directory.format(self.data_source['experiment']['instrument'], self.year, self.visit_id)
+        directory_path = directory.format(self.metadata['data source']['experiment']['instrument'], self.year, self.visit_id)
         if path.isdir(directory_path):
             self.directory_path = directory_path
         else:
@@ -99,7 +99,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=met
     the_boss.metadata['reduction']['input files']['datafile'] = [directory + str(r) for r in run_numbers]
     keys = recipe.keys()
     if 'instrument' in keys:
-        the_boss.metadata['data_source']['experiment']['instrument'] = recipe['instrument']
+        the_boss.metadata['data source']['experiment']['instrument'] = recipe['instrument']
         the_boss.parser = function_map[recipe['instrument']]
     else:
         raise ValueError("No instrument given in {}.".format(yaml_file))
